@@ -11,7 +11,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import fnmatch
 import functools
 import itertools
 import os
@@ -25,8 +24,9 @@ from oslo_log import log
 import oslo_messaging
 
 from ceilometer.agent import plugin_base
-from ceilometer.i18n import _LE
+from ceilometer.i18n import _LE, _LW
 from ceilometer import sample
+from ceilometer import utils
 
 OPTS = [
     cfg.StrOpt('meter_definitions_cfg_file',
@@ -106,7 +106,7 @@ class MeterDefinition(object):
 
     def match_type(self, meter_name):
         for t in self._event_type:
-            if fnmatch.fnmatch(meter_name, t):
+            if utils.match(meter_name, t):
                 return True
 
     def parse_fields(self, field, message, all_values=False):
@@ -182,10 +182,24 @@ def setup_meters_config():
 def load_definitions(config_def):
     if not config_def:
         return []
-    return [MeterDefinition(event_def)
-            for event_def in reversed(config_def['metric'])
-            if (event_def['volume'] != 1 or
-                not cfg.CONF.notification.disable_non_metric_meters)]
+    meter_defs = {}
+    for event_def in reversed(config_def['metric']):
+        if event_def.get('name') in meter_defs:
+            # skip duplicate meters
+            LOG.warning(_LW("Skipping duplicate meter definition %s")
+                        % event_def)
+            continue
+
+        try:
+            if (event_def.get('volume') != 1 or
+                    not cfg.CONF.notification.disable_non_metric_meters):
+                md = MeterDefinition(event_def)
+                meter_defs[event_def['name']] = md
+        except MeterDefinitionException as me:
+            errmsg = (_LE("Error loading meter definition : %(err)s")
+                      % dict(err=me.message))
+            LOG.error(errmsg)
+    return meter_defs.values()
 
 
 class InvalidPayload(Exception):
@@ -227,7 +241,8 @@ class ProcessMeterNotifications(plugin_base.NotificationBase):
         for exchange in exchanges:
             targets.extend(oslo_messaging.Target(topic=topic,
                                                  exchange=exchange)
-                           for topic in conf.notification_topics)
+                           for topic in
+                           self.get_notification_topics(conf))
         return targets
 
     @staticmethod
