@@ -59,8 +59,7 @@ class NetworkNotificationBase(plugin_base.NotificationBase):
             # '%s.delete.start' % (self.resource_name),
         ]
 
-    @staticmethod
-    def get_targets(conf):
+    def get_targets(self, conf):
         """Return a sequence of oslo_messaging.Target
 
         This sequence is defining the exchange and topics to be connected for
@@ -68,7 +67,7 @@ class NetworkNotificationBase(plugin_base.NotificationBase):
         """
         return [oslo_messaging.Target(topic=topic,
                                       exchange=conf.neutron_control_exchange)
-                for topic in conf.notification_topics]
+                for topic in self.get_notification_topics(conf)]
 
     def process_notification(self, message):
         counter_name = getattr(self, 'counter_name', self.resource_name)
