@@ -33,7 +33,6 @@ from ceilometer.compute.notifications import instance
 from ceilometer import messaging
 from ceilometer import notification
 from ceilometer.publisher import test as test_publisher
-from ceilometer import service
 from ceilometer.tests import base as tests_base
 
 TEST_NOTICE_CTXT = {
@@ -219,7 +218,7 @@ class BaseRealNotification(tests_base.BaseTestCase):
         super(BaseRealNotification, self).setUp()
         self.CONF = self.useFixture(fixture_config.Config()).conf
         # Dummy config file to avoid looking for system config
-        service.prepare_service(argv=[], config_files=[])
+        self.CONF([], project='ceilometer', validate_default_values=True)
         self.setup_messaging(self.CONF, 'nova')
 
         pipeline_cfg_file = self.setup_pipeline(['instance', 'memory'])
@@ -283,6 +282,7 @@ class TestRealNotificationReloadablePipeline(BaseRealNotification):
         pipeline_poller_call = mock.call(1, self.srv.refresh_pipeline)
         self.assertIn(pipeline_poller_call,
                       self.srv.tg.add_timer.call_args_list)
+        self.srv.stop()
 
     @mock.patch('ceilometer.publisher.test.TestPublisher')
     def test_notification_reloaded_pipeline(self, fake_publisher_cls):
@@ -337,6 +337,7 @@ class TestRealNotificationReloadablePipeline(BaseRealNotification):
 
         (self.assertIn(sample.name, ['disk.root.size', 'vcpus'])
          for sample in self.publisher.samples)
+        self.srv.stop()
 
     @mock.patch('ceilometer.publisher.test.TestPublisher')
     def test_notification_reloaded_event_pipeline(self, fake_publisher_cls):
@@ -392,6 +393,7 @@ class TestRealNotificationReloadablePipeline(BaseRealNotification):
 
         self.assertEqual(self.publisher.events[0].event_type,
                          'compute.instance.create.end')
+        self.srv.stop()
 
 
 class TestRealNotification(BaseRealNotification):
@@ -538,7 +540,7 @@ class TestRealNotificationMultipleAgents(tests_base.BaseTestCase):
     def setUp(self):
         super(TestRealNotificationMultipleAgents, self).setUp()
         self.CONF = self.useFixture(fixture_config.Config()).conf
-        service.prepare_service(argv=[], config_files=[])
+        self.CONF([], project='ceilometer', validate_default_values=True)
         self.setup_messaging(self.CONF, 'nova')
 
         pipeline_cfg_file = self.setup_pipeline(['instance', 'memory'])
